//! A module to re-export types that are visible through the ic-agent API.
pub use crate::ic_types::{Principal, PrincipalError};
